<?php
namespace Teknisa\CADFIS\Strategies;

use Teknisa\Libs\Util\Environment;
use Teknisa\CADFIS\Strategies\GeneralStrategy;
use Teknisa\CADFIS\Services\CompradorService as CompradorService;

class CompradorStrategy extends GeneralStrategy implements Interfaces\IStrategy
{
    protected $service;
    protected $errors = array();
    
    public function __construct(CompradorService $service, Environment $environment)
    {
		$this->service = $service;
		$this->environment = $environment;
	}
	
	public function validate(&$data)
    {
        //parent::verifyIsEmpty($data);
        
        foreach ($data as &$row) {
            parent::verifyIsEmpty($row, $row["ROWNUM"], ['CDOPERADOR', 'VRLIMAFCOMP', 'VRLIMAFMES']);
            parent::verifyCdOperador($row, $row["ROWNUM"], 'CDOPERADOR');
            self::verifyCompradorExists($row, $row["ROWNUM"]);
            self::verifyVrLimitAfComp($row, $row["ROWNUM"]);
            self::verifyVrLimitAfMes($row, $row["ROWNUM"]);
            
            $row['ERROS'] = $this->errors;
            
            parent::clearErrors();
        }
    }
    
    private function verifyCompradorExists($row, $rowNum)
    {
        if ($this->service->verifyCompradorExists($row)) {
            parent::setError($rowNum, 'CDOPERADOR', $row['CDOPERADOR'], "ALREADY_REGISTERED");
        }
    }
    
    private function verifyVrLimitAfComp($row, $rowNum)
    {
        $columnName = 'VRLIMAFCOMP';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
        }
    }
    
    private function verifyVrLimitAfMes($row, $rowNum)
    {
        $columnName = 'VRLIMAFMES';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
        }
    }
    
    public function formatToView(&$data)
    {
        foreach ($data as &$row) {
           $row['CDOPERADOR'] = parent::formatColumn($row['CDOPERADOR'], 12);
           $row['IDERROR'] = !empty($row['ERROS']) ? 'S' : 'N';
        }
    }
    
    public function save($data)
    {
        self::validate($data);
        parent::verifyExistErros($data);
        $this->service->saveImport($data);
    }
}