IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'GERA_APURACAO_CONTRIBUICOES' AND
	        TYPE = 'P' 			       AND
	        U.UID = O.UID             	       AND
	        U.NAME = USER)
DROP PROCEDURE GERA_APURACAO_CONTRIBUICOES
GO


create procedure GERA_APURACAO_CONTRIBUICOES(
    @P_DTINICIAL       DATETIME,
    @P_DTFINAL         DATETIME,
    @P_IDIMPORECUPNFE  VARCHAR(1),
    @P_CDIMPOSTONFE    VARCHAR(2),
    @P_NRSEQUMAPAPU    VARCHAR(10),
    @P_CDEMPRESA       VARCHAR(2))
AS
BEGIN
   DECLARE @V_IDFORMAPUR   VARCHAR(1);/*IDICAO DA FORMA DE APURAO*/
   DECLARE @V_VCENTR       DOUBLE PRECISION;/*VALOR CONTABIL DE ENTRADA*/
   DECLARE @V_BCENTR       DOUBLE PRECISION;/*BASE DE CALCULO DAS ENTRADAS*/
   DECLARE @V_VRIMPENTR    DOUBLE PRECISION;/*VALOR DO IMPOSTO DAS ENTRADAS - CREDITOS*/
   DECLARE @V_VCSAIDA      DOUBLE PRECISION;/*VALOR CONTBIL SAIDA*/
   DECLARE @V_BCSAIDA      DOUBLE PRECISION;/*BASE CALCULO SAIDA*/
   DECLARE @V_OUTRRECSAIDA DOUBLE PRECISION;/*OUTRAS RECEITAS CONTAS CONTBEIS SAIDA*/
   DECLARE @V_IMPNCUMSAIDA DOUBLE PRECISION;/*IMPOSTO NO CUMULATIVO SAIDA*/
   DECLARE @V_IMPCUMSAIDA  DOUBLE PRECISION;/*IMPOSTO CUMULATIVO SAIDA*/
   DECLARE @V_VRIMPECF     DOUBLE PRECISION;/*VALOR DE IMPOSTO DOS ECF'S*/
   DECLARE @V_COMPENSACOES DOUBLE PRECISION;/*VALOR DAS COMPENSAES*/
   DECLARE @V_VRTOTAIMPREC DOUBLE PRECISION;/*VALOR DO IMPOSTO A RECOLHER*/
   DECLARE @V_VRCREPERANT  DOUBLE PRECISION;/*VALOR DO CREDITO DO PERIODO ANTERIOR*/
   DECLARE @V_VRSALDOCRED  DOUBLE PRECISION;/*VALOR DO SALDO CREDOR*/
   DECLARE @V_VRDEDUCAO    DOUBLE PRECISION;/*VALOR DAS DEDUES*/
   DECLARE @V_VRAJUSTACRES FLOAT;/*AJUSTE A ACRSCIMO*/
   DECLARE @V_VRAJUSTREDU  FLOAT;/*VRAJUSTE REDUCAO*/
   DECLARE @V_VRDEVOLCUM   FLOAT;/*VALOR DE CANCELAMENTOS/DEVOLUES DE VENDAS - CUMULATIVO*/
   DECLARE @V_VRDEVOLNCUM  FLOAT;/*VALOR DE CANCELAMENTOS/DEVOLUES DE VENDAS - NO CUMULATIVO*/
   DECLARE @V_VRIMPDEVCUM  FLOAT;/*VALOR DE IMPOSTO DE CANCELAMENTOS/DEVOLUES DE VENDAS - CUMULATIVO*/
   DECLARE @V_VRIMPDEVNCUM FLOAT;/*VALOR DE IMPOSTO DE CANCELAMENTOS/DEVOLUES DE VENDAS - NO CUMULATIVO*/
   DECLARE @V_DTINIFORPER  DATETIME; /*DATA INICIAL PARA NOTAS FORA DO PERIODO*/
   DECLARE @V_CDIMPCOMPEN  VARCHAR(2);/*IMPOSTO DE COMPENSAO(PIS RETIDO OU COFINS RETIDO)*/
   DECLARE @V_IDNFFORAPERAPU VARCHAR(1);/*PARAMETRO VINCULA NF FORA DO PERODO NO MAPA*/


   /*----VERIFICA A FORMA DE APURAO DOS IMPOSTOS(COMPETNCIA, PAGAMENTO, EMISSAO, ENTRADA/SAIDA)----*/
   SELECT @V_IDFORMAPUR = MAX(IDFORMAPUR)
     FROM IMPOSTO I
    WHERE I.CDIMPOSTONFE = @P_CDIMPOSTONFE;

  /*BUSCA A DATA INICIAL PARA AS NOTAS FORA DO PERODO*/
   SELECT @V_DTINIFORPER = DTININFFORPER
    FROM PARAMFISCAL;

   /*BUSCA O VALO DE AJUSTES A REDUO NO MAPA*/
   SELECT @V_VRAJUSTREDU = SUM(VRAJUSTE)
    FROM AJUSTEAPURCONTR
   WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU
     AND IDTPAJUSTE = '0';

   /*BUSCA O VALO DE AJUSTES A ACRESCIMO NO MAPA*/
   SELECT @V_VRAJUSTACRES = SUM(VRAJUSTE)
    FROM AJUSTEAPURCONTR
   WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU
     AND IDTPAJUSTE = '1';

  /*BUSCA O VALOR DE DEDUO E CREDITO DO PERIODO ANTERIOR DO MAPA(EM CASO DE APURAO MANUAL)*/
   SELECT @V_VRCREPERANT = SUM(VRCREDPERANT), @V_VRDEDUCAO = SUM(VRDEDUCAO)
    FROM DETAPURACONTR D
   WHERE D.NRSEQUMAPAPU = @P_NRSEQUMAPAPU;

   /*UPDATE DAS NOTAS NA IMPOSTONF PARA NULL EM CASO DE REAPURAO DE MAPAS */
   UPDATE IMPOSTONF
     SET NRSEQUMAPAPU = NULL
   WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU;

  /*BUSCA O SALDO DO PERIODO ANTERIOR(SALDO CREDOR GRAVADO NO MAPA ANTERIOR)*/
   IF @@ROWCOUNT = 0 AND  ISNULL(@V_VRCREPERANT,0) = 0 BEGIN
      SELECT @V_VRCREPERANT = SUM(VRSALDOCRED)
       FROM DETAPURACONTR D, MAPAAPURAC M
      WHERE M.CDEMPRESA    = @P_CDEMPRESA
        AND M.CDIMPOSTO    = @P_CDIMPOSTONFE
        AND M.NRSEQUMAPAPU = D.NRSEQUMAPAPU
        AND DTFIMPERIODO   = @P_DTINICIAL - 1;
   END;

   /*BUSCA PARAMETRO PARA VINCULAR NFS*/
   SELECT @V_IDNFFORAPERAPU = ISNULL(IDNFFORAPERAPU,'N')
     FROM PARAMFISCAL;

------------------------------------------------/*APURAO IMPOSTOS PRINCIPAIS(PIS OU COFINS)*/---------------------------

   /*-------------------APURAO IMPOSTO POR DATA DE COMPETNCIA-------------*/
   IF @V_IDFORMAPUR = 'C' BEGIN
     /*UPDATE DAS NOTAS O NRSEQUMAPAPU ATUAL*/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = @P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPU IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @P_CDIMPOSTONFE)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           AND IDENTRSAIDOP = 'E'
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN
                                                  CASE WHEN IDENTRSAIDOP = 'S' THEN DTEMISSAO ELSE DTENTRSAID END
                                               ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS'
                                        UNION ALL
                                        SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           AND IDENTRSAIDOP = 'S'
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN
                                                  CASE WHEN IDENTRSAIDOP = 'S' THEN DTEMISSAO ELSE DTENTRSAID END
                                               ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');

   END;
  /*-------------------APURAO IMPOSTO POR DATA DE ENTRADA/SAIDA-------------*/
   IF @V_IDFORMAPUR = 'D' BEGIN

      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = @P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPU IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @P_CDIMPOSTONFE)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN DTENTRSAID ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');

   END;
  /*-------------------APURAO IMPOSTO POR DATA DE EMISSAO-------------*/
   IF @V_IDFORMAPUR = 'E' BEGIN

      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = @P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPU IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @P_CDIMPOSTONFE)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN DTEMISSAO ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');

   END;

  /*-------------------APURAO IMPOSTO POR DATA DE PAGAMENTO-------------*/
   IF @V_IDFORMAPUR = 'P' BEGIN
      /*MARCA NOTAS ENTRADAS*/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = @P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPU IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @P_CDIMPOSTONFE)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT N.NRLANCTONF + N.CDFILIAL
                                          FROM NOTAFISCAL N, CONTAPAGAR C,BOLETPAGAR B,BAIXAPAGA BX
                                         WHERE N.CDEMPRESA  = @P_CDEMPRESA
                                           AND IDSTATUS  IN ('A','E')
                                           AND IDENTRSAIDOP = 'E'
                                           AND N.CDFILIAL = C.CDFILIAL
                                           AND N.NRLANCTONF = C.NRLANCTONF
                                           AND IMPOSTONF.CDFILIAL = C.CDFILIAL
                                           AND IMPOSTONF.NRLANCTONF = C.NRLANCTONF
                                           AND C.CDFILIBPAG   = B.CDFILIAL
                                           AND C.NRLANBOLPAG  = B.NRLANBOLPAG
                                           AND B.CDFILIBAIPAG = BX.CDFILIAL
                                           AND B.NRBAIXAPAG   = BX.NRBAIXAPAG
                                           AND BX.CDEMPRESA   = @P_CDEMPRESA
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN BX.DTBAIXAPAG ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (BX.DTBAIXAPAG BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (BX.DTBAIXAPAG BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (BX.DTBAIXAPAG BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');


      /*MARCA NOTAS SAIDAS*/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = @P_NRSEQUMAPAPU
       WHERE NRSEQUMAPAPU IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @P_CDIMPOSTONFE)
         AND (CDFILIAL+NRLANCTONF) IN (SELECT N.CDFILIAL+N.NRLANCTONF
                                         FROM NOTAFISCAL N, CONTARECEBER C,BOLETRECEBER B,BAIXARECEBIDA BX
                                        WHERE N.CDEMPRESA  = @P_CDEMPRESA
                                          AND IDSTATUS  IN ('A','E')
                                          AND IDENTRSAIDOP = 'S'
                                          AND N.CDFILIAL = C.CDFILIAL
                                          AND N.NRLANCTONF = C.NRLANCTONF
                                          AND IMPOSTONF.CDFILIAL = C.CDFILIAL
                                          AND IMPOSTONF.NRLANCTONF = C.NRLANCTONF
                                          AND C.CDFILIBOLREC = B.CDFILIAL
                                          AND C.NRLANBOLREC  = B.NRLANBOLREC
                                          AND B.CDFILIBAIREC = BX.CDFILIAL
                                          AND B.NRBAIXAREC   = BX.NRBAIXAREC
                                          AND BX.CDEMPRESA   = @P_CDEMPRESA
                                          /*AND CASE WHEN DTREFMAPAPU IS NULL THEN BX.DTBAIXAREC ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                          AND (((@V_IDNFFORAPERAPU='N') AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                          AND IDSISTEMA <> 'PAG'
                                          AND IDSISTEMA <> 'REC'
                                          AND IDSISTEMA <> 'FIS');

   END;

   /*---CALCULO DO VALOR CONTBIL, BASE DE CLCULO E IMPOSTO DAS ENTRADAS-----*/
   SELECT @V_VCENTR    = SUM(VRCONTABILNF),
          @V_BCENTR    = SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRBASECALCNF ELSE 0 END) ELSE VRBASECALCNF END),
          @V_VRIMPENTR = SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRIMPOSTONF ELSE 0 END) ELSE VRIMPOSTONF END)
     FROM IMPOSTONF I, NOTAFISCAL N
    WHERE NRSEQUMAPAPU   = @P_NRSEQUMAPAPU
      AND I.NRLANCTONF   = N.NRLANCTONF
      AND I.CDFILIAL     = N.CDFILIAL
      AND N.CDEMPRESA    = @P_CDEMPRESA
      AND N.IDENTRSAIDOP = 'E';

   /*---CLCULO DO VALOR CONTBIL, BASE DE CLCULO E IMPOSTO DAS SADAS-----*/
   SELECT @V_VCSAIDA      = SUM(VRCONTABIL),
          @V_BCSAIDA      = SUM(VRBASECALC),
          @V_OUTRRECSAIDA = SUM(VROUTRREC),
          @V_IMPNCUMSAIDA = SUM(VRIMPNAOCUMU),
          @V_IMPCUMSAIDA  = SUM(VRIMPCUMU),
          @V_VRIMPECF     = SUM(VRIMPECF),
          @V_VRDEVOLNCUM  = SUM(VRDEVOLNCUM),
          @V_VRDEVOLCUM   = SUM(VRDEVOLCUM)
   FROM(SELECT SUM(VRCONTABILNF) AS VRCONTABIL,/*NOTAS NO CUMULATIVO*/
                SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRBASECALCNF ELSE 0 END) ELSE VRBASECALCNF END) AS VRBASECALC,
                SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRIMPOSTONF ELSE 0 END) ELSE VRIMPOSTONF END) AS VRIMPNAOCUMU,
                0 AS VRIMPCUMU,
                0 AS VROUTRREC , 0 AS VRIMPECF,
                0 AS VRDEVOLNCUM,
                0 AS VRDEVOLCUM
           FROM IMPOSTONF I, NOTAFISCAL N, FILIAL F
          WHERE NRSEQUMAPAPU     = @P_NRSEQUMAPAPU
            AND I.NRLANCTONF     = N.NRLANCTONF
            AND I.CDFILIAL       = N.CDFILIAL
            AND F.CDFILIAL       = N.CDFILIEMIT
            AND N.CDEMPRESA      = @P_CDEMPRESA
            AND N.IDENTRSAIDOP   = 'S'
            AND F.IDCUMUPISCOFIL = 'S'
         /*NOTAS CUMULATIVA*/
         UNION ALL
         SELECT SUM(VRCONTABILNF) AS VRCONTABIL,
                SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRBASECALCNF ELSE 0 END) ELSE VRBASECALCNF END) AS VRBASECALC,
                0 AS VRIMPNAOCUMU,
                SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRIMPOSTONF ELSE 0 END) ELSE VRIMPOSTONF END) AS VRIMPCUMU,
                0 AS VROUTRREC, 0 AS VRIMPECF,
                0 AS VRDEVOLNCUM,
                0 AS VRDEVOLCUM
           FROM IMPOSTONF I, NOTAFISCAL N, FILIAL F
          WHERE NRSEQUMAPAPU     = @P_NRSEQUMAPAPU
            AND I.NRLANCTONF     = N.NRLANCTONF
            AND I.CDFILIAL       = N.CDFILIAL
            AND F.CDFILIAL       = N.CDFILIEMIT
            AND N.CDEMPRESA      = @P_CDEMPRESA
            AND N.IDENTRSAIDOP   = 'S'
            AND F.IDCUMUPISCOFIL = 'N'
            UNION ALL
           /*OUTRAS RECEITAS NO CUMULATIVAS*/
           SELECT 0 AS VRCONTABIL,
                  SUM(ROUND(CASE WHEN CDSITUTRIBPICO IN ('01','02','03','05') THEN LC.VRLANCAMENT ELSE 0 END,4)) AS VRBASECALC,
                  SUM(ROUND(((CASE WHEN CDSITUTRIBPICO IN ('01','02','03','05') THEN LC.VRLANCAMENT ELSE 0 END) * (CASE WHEN @P_CDIMPOSTONFE = '50' THEN VRALIQPIS ELSE VRALIQCOFINS END) )/100,2)) AS VRIMPNAOCUMU,
                  0 AS VRIMPCUMU,
                  SUM(ABS(LC.VRLANCAMENT)) AS VROUTRREC, 0 AS VRIMPECF,
                  0 AS VRDEVOLNCUM,
                  0 AS VRDEVOLCUM
             FROM OUTRECCONT OT, OUTRECCONTCTBL OTC , LANCCONT LC, EMPRESA E
            WHERE OT.CDOUTRECCONT =  OTC.CDOUTRECCONT
              AND LC.CDCONTCTBL LIKE OTC.CDCONTCTBL+'%'
              AND LC.DTLANCCONT BETWEEN @P_DTINICIAL AND @P_DTFINAL
              AND LC.CDEMPRESA = @P_CDEMPRESA
              AND LC.CDEMPRESA = E.CDEMPRESA
              AND LC.VRLANCAMENT > 0
              AND CASE WHEN @P_CDIMPOSTONFE = '50' THEN VRALIQPIS ELSE VRALIQCOFINS END <> CASE WHEN @P_CDIMPOSTONFE = '50' THEN 0.65 ELSE 3 END
            UNION ALL
           /*OUTRAS RECEITAS CUMULATIVAS*/
           SELECT 0 AS VRCONTABIL,
                  SUM(ROUND(CASE WHEN CDSITUTRIBPICO IN ('01','02','03','05') THEN LC.VRLANCAMENT ELSE 0 END,4)) AS VRBASECALC,
                  0 AS VRIMPNAOCUMU,
                  SUM(ROUND(((CASE WHEN CDSITUTRIBPICO IN ('01','02','03','05') THEN LC.VRLANCAMENT ELSE 0 END) * CASE WHEN @P_CDIMPOSTONFE = '50' THEN VRALIQPIS ELSE VRALIQCOFINS END)/100,2)) AS VRIMPCUMU,
                  SUM(ABS(LC.VRLANCAMENT)) AS VROUTRREC, 0 AS VRIMPECF,
                  0 AS VRDEVOLNCUM,
                  0 AS VRDEVOLCUM
             FROM OUTRECCONT OT, OUTRECCONTCTBL OTC , LANCCONT LC, EMPRESA E
            WHERE OT.CDOUTRECCONT =  OTC.CDOUTRECCONT
              AND LC.CDCONTCTBL LIKE OTC.CDCONTCTBL+'%'
              AND LC.DTLANCCONT BETWEEN @P_DTINICIAL AND @P_DTFINAL
              AND LC.CDEMPRESA = @P_CDEMPRESA
              AND LC.CDEMPRESA = E.CDEMPRESA
              AND LC.VRLANCAMENT > 0
              AND CASE WHEN @P_CDIMPOSTONFE = '50' THEN VRALIQPIS ELSE VRALIQCOFINS END = CASE WHEN @P_CDIMPOSTONFE = '50' THEN 0.65 ELSE 3 END
           UNION ALL
          /*RECEITAS ECF NO-CUMULATIVA*/
           SELECT SUM(VRPRODUTO) AS VRCONTABIL,
                  SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN CASE WHEN CDFISCALIT = '1' THEN I.VRPRODUTO  ELSE 0 END ELSE I.VRPRODUTO END ) AS VRBASECALC,
                  0 AS VRIMPNAOCUMU,
                  0 AS VRIMPCUMU,
                  0 AS VROUTRREC,
                  SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN ((VRPRODUTO*(CASE WHEN CDFISCALIT = '1' THEN VRALIQIT ELSE 0 END))/100) ELSE (VRPRODUTO*(VRALIQIT/100)) END),
                  0 AS VRDEVOLNCUM,
                  0 AS VRDEVOLCUM
            FROM ITEMVENOUTIMPOS I, FILIAL F, IMPOSTO IM
           WHERE I.CDFILIAL       = F.CDFILIAL
             AND IM.CDIMPOSTONFE  = @P_CDIMPOSTONFE
             AND F.CDEMPRESA      = @P_CDEMPRESA
             AND I.DTREDUCAOZ BETWEEN @P_DTINICIAL AND @P_DTFINAL
             AND I.CDIMPOSTO      = IM.CDIMPOSTO
           UNION ALL
           /*VENDAS CANCELADAS/DEVOLUO DE VENDAS - SEM IPI*/
           SELECT 0 AS VRCONTABIL,
                  0 AS VRBASECALC,
                  0 AS VRIMPNAOCUMU,
                  0 AS VRIMPCUMU,
                  0 AS VROUTRREC,
                  0 AS VRIMPECF,
                  SUM(CASE WHEN F.IDCUMUPISCOFIL='S' THEN VRCONTABILNF- TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, '10', 'I', '1') ELSE 0 END) AS VRDEVOLNCUM,
                  SUM(CASE WHEN F.IDCUMUPISCOFIL='N' THEN VRCONTABILNF- TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, '10', 'I', '1') ELSE 0 END) AS VRDEVOLCUM
             FROM NOTAFISCAL N, IMPOSTONF I, FILIAL F
            WHERE CDTIPOOPER IN ('23', '31', '32', '33', '34')
              AND IDSTATUS IN ('E', 'A')
              AND IDENTRSAIDOP = 'E'
              AND I.CDFILIAL = N.CDFILIAL
              AND I.NRLANCTONF = N.NRLANCTONF
              AND NRSEQUMAPAPU = @P_NRSEQUMAPAPU
              AND F.CDFILIAL = N.CDFILIRECE)DADOS;

--------------------------------------/*CLCULO DAS COMPENSAPES*/-------------------------------------------------------
   IF @P_CDIMPOSTONFE = '50' BEGIN

      SET @V_CDIMPCOMPEN = '55';

   END;
   IF @P_CDIMPOSTONFE = '60' BEGIN

      SET @V_CDIMPCOMPEN = '65';

   END;

   /*SELECIONA A FORMA DE APURAO DO IMPOSTO RETIDO NA FONTE*/
   SELECT @V_IDFORMAPUR = MAX(IDFORMAPUR)
     FROM IMPOSTO I
    WHERE I.CDIMPOSTONFE = @V_CDIMPCOMPEN;


   /*UPDATE DAS NOTAS DE COMPENSAO. APENAS NOTAS DE SADA, J QUE TRATA-SE DE COMPENSAO DE VALOR RETIDO POR CLIENTE*/
   /*ATUALIZA-SE NESTE CASO O CAMPO NRSEQMAPOIMP*/


   /*UPDATE DAS NOTAS NA IMPOSTONF PARA NULL EM CASO DE REAPURAO DE MAPAS */
   UPDATE IMPOSTONF
     SET NRSEQMAPOIMP = NULL
   WHERE NRSEQMAPOIMP = @P_NRSEQUMAPAPU;


   /*-------------------APURAO IMPOSTO POR DATA DE COMPETNCIA-------------*/
   IF @V_IDFORMAPUR = 'C' BEGIN
      UPDATE IMPOSTONF
         SET NRSEQMAPOIMP = @P_NRSEQUMAPAPU
       WHERE NRSEQMAPOIMP IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @V_CDIMPCOMPEN)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           AND IDENTRSAIDOP = 'S'
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN DTEMISSAO ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTEMISSAO BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');

   END;
  /*-------------------APURAO IMPOSTO POR DATA DE ENTRADA/SAIDA-------------*/
   IF @V_IDFORMAPUR = 'D' BEGIN

      UPDATE IMPOSTONF
         SET NRSEQMAPOIMP = @P_NRSEQUMAPAPU
       WHERE NRSEQMAPOIMP IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @V_CDIMPCOMPEN)
         AND (NRLANCTONF+CDFILIAL) IN (SELECT NRLANCTONF+CDFILIAL
                                          FROM NOTAFISCAL
                                         WHERE IDSTATUS IN ('E','A')
                                           AND CDEMPRESA = @P_CDEMPRESA
                                           AND IDENTRSAIDOP = 'S'
                                           /*AND CASE WHEN DTREFMAPAPU IS NULL THEN DTENTRSAID ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                           AND (((@V_IDNFFORAPERAPU='N') AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (DTENTRSAID BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                           AND IDSISTEMA <> 'PAG'
                                           AND IDSISTEMA <> 'REC'
                                           AND IDSISTEMA <> 'FIS');

   END;
  /*-------------------APURAO IMPOSTO POR DATA DE PAGAMENTO-------------*/
   IF @V_IDFORMAPUR = 'P' BEGIN

      UPDATE IMPOSTONF
         SET NRSEQMAPOIMP = @P_NRSEQUMAPAPU
       WHERE NRSEQMAPOIMP IS NULL
         AND CDIMPOSTO IN (SELECT CDIMPOSTO
                             FROM IMPOSTO I
                            WHERE I.CDIMPOSTONFE =  @V_CDIMPCOMPEN)
         AND (CDFILIAL+NRLANCTONF) IN (SELECT N.CDFILIAL+N.NRLANCTONF
                                         FROM NOTAFISCAL N, CONTARECEBER C,BOLETRECEBER B,BAIXARECEBIDA BX
                                        WHERE N.CDEMPRESA  = @P_CDEMPRESA
                                          AND IDSTATUS  IN ('A','E')
                                          AND IDENTRSAIDOP = 'S'
                                          AND N.CDFILIAL = C.CDFILIAL
                                          AND N.NRLANCTONF = C.NRLANCTONF
                                          AND IMPOSTONF.CDFILIAL = C.CDFILIAL
                                          AND IMPOSTONF.NRLANCTONF = C.NRLANCTONF
                                          AND C.CDFILIBOLREC = B.CDFILIAL
                                          AND C.NRLANBOLREC  = B.NRLANBOLREC
                                          AND B.CDFILIBAIREC = BX.CDFILIAL
                                          AND B.NRBAIXAREC   = BX.NRBAIXAREC
                                          AND BX.CDEMPRESA   = @P_CDEMPRESA
                                          /*AND CASE WHEN DTREFMAPAPU IS NULL THEN BX.DTBAIXAREC ELSE DTREFMAPAPU END BETWEEN @V_DTINIFORPER AND @P_DTFINAL*/
                                          AND (((@V_IDNFFORAPERAPU='N') AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU IS NULL) AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)) OR
                                                ((@V_IDNFFORAPERAPU='S') AND (DTREFMAPAPU BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND (BX.DTBAIXAREC BETWEEN @V_DTINIFORPER AND @P_DTFINAL)))
                                          AND IDSISTEMA <> 'PAG'
                                          AND IDSISTEMA <> 'REC'
                                          AND IDSISTEMA <> 'FIS');
   END;

   /*--------------ClCUlO DA COMPENSAO-------------*/
   SELECT @V_COMPENSACOES = SUM(CASE WHEN @P_IDIMPORECUPNFE = 'S' THEN (CASE WHEN CDFISCALNF = '1' THEN VRIMPOSTONF ELSE 0 END) ELSE VRIMPOSTONF END)
     FROM IMPOSTONF
   WHERE NRSEQMAPOIMP = @P_NRSEQUMAPAPU;

-----------------------------------/*INSERT DOS DADOS CALCULADOS*/--------------------------------------------------------


   /*---------------------------CLCUlO DO IMPOSTO TOTAL-----------------------------------------------------*/
   SET @V_VRTOTAIMPREC =  (ISNULL(@V_IMPNCUMSAIDA,0)+ ISNULL(@V_IMPCUMSAIDA,0)+ ISNULL(@V_VRIMPECF,0)+ ISNULL(@V_VRAJUSTACRES,0) ) -
                          (ISNULL(@V_VRIMPENTR,0)+ ISNULL(@V_VRCREPERANT,0)+ISNULL(@V_COMPENSACOES,0)+ISNULL(@V_VRAJUSTREDU,0));
   IF ISNULL(@V_VRTOTAIMPREC,0) < 0 BEGIN
     SET @V_VRSALDOCRED  =  ABS(ISNULL(@V_VRTOTAIMPREC,0));
     SET @V_VRTOTAIMPREC = 0;
   END;

   /*---------------------------UPDATE DA MAPAAPURAC COM OS VALORES APURADOS--------------------------------*/
   UPDATE MAPAAPURAC
      SET VRTTCTBLDEB  = ISNULL(@V_VCSAIDA,0),
          VRTTBACALDEB = ISNULL(@V_BCSAIDA-(@V_VRDEVOLNCUM+@V_VRDEVOLCUM),0),
          VRTTCTBLCRE  = ISNULL(@V_VCENTR,0),
          VRTTBACALCRE = ISNULL(@V_BCENTR,0),
          VRTOTAIMPOS  = ISNULL(@V_VRTOTAIMPREC,0),
          VRTOTAGUIA   = (ISNULL(@V_VRTOTAIMPREC,0) + ISNULL(VRMULTAGUIA,0) + ISNULL(VRJUROGUIA,0)),
          IDBLOQMAPAPU = 'A'
   WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU;

   /*---------------------------INSERO DA TABELA DE DE DETALHES-------------------------------------------*/
   DELETE FROM DETAPURACONTR
    WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU;

   INSERT INTO DETAPURACONTR
          (NRSEQUMAPAPU, VRCREDENTR, VRDEDUCAO, VRCREDATIVIMOB, VRDEBNCUMULA, VRDEBCUMULA,
           VRDEBECF, VRCOMPENSA, VROUTRECCONT, VRSALDOCRED, VRCREDPERANT, VRCANCDEVOL)
        VALUES
          (@P_NRSEQUMAPAPU, ISNULL(@V_VRIMPENTR,0), ISNULL(@V_VRDEDUCAO,0), 0, ISNULL(@V_IMPNCUMSAIDA,0), ISNULL(@V_IMPCUMSAIDA,0),
           ISNULL(@V_VRIMPECF,0),ISNULL(@V_COMPENSACOES,0), ISNULL(@V_OUTRRECSAIDA,0),ISNULL(@V_VRSALDOCRED,0),ISNULL(@V_VRCREPERANT,0),
           ISNULL(@V_VRDEVOLNCUM+@V_VRDEVOLCUM,0));

---------------------------------------------/*VINCULA NFS COM O MAPA*/--------------------------------------------
   IF @V_IDNFFORAPERAPU = 'S' BEGIN
      UPDATE NOTAFISCAL
         SET DTREFMAPAPU = @P_DTINICIAL
       WHERE (CDFILIAL+NRLANCTONF) IN (SELECT DISTINCT CDFILIAL+NRLANCTONF
                                         FROM IMPOSTONF
                                        WHERE NRSEQUMAPAPU = @P_NRSEQUMAPAPU);
   END;

END;
GO
-- VERSAO --
EXEC ATUVEROBJ 'GERA_APURACAO_CONTRIBUICOES','5.45.000';
GO

